
****************
Installation
****************


From PyPI
#########

TLDR - do this at your own risk
-------------------------------

.. code:: bash

    pip install badwing

Recommended - pipX
------------------

If you don't already have it installed go to https://pypi.org/project/pipx/ for instructions

.. code:: bash

    pipx install badwing

And then run it!
----------------

.. code:: bash

    badwing run


From GitHub
###########

Clone the repository

.. code:: bash

        git clone https://github.com/kfields/badwing.git
        
Navigate to the new directory which contains the repository

.. code:: bash

        cd badwing

Create a Python 3 virtual environment called `env`

.. code:: bash

        python3 -m venv env
        
Activate the environment

.. code:: bash

        source env/bin/activate
        
Install required packages

.. code:: bash

        pip install -r requirements.txt


And then run the game!
----------------------

.. code:: bash

    python run_game.py

